%PLOT_INTERPRET_FIGS Plots the figures for interpretation

%
% Parameters
%
fontsize = 18;
resdir = '../results/real/';
datadir = '../data/';
figdir = '../figs/';

% helper programs
convert = '/usr/local/bin/convert/';
pdfcrop = '/Library/TeX/texbin/pdfcrop';

%
% Face data
%

load([resdir 'eigenfaces.mat']);

% Parameter 
h = figure;
imagesc(reshape(col, 32, 32), [-5, 5]);
axis equal
axis tight
set(gca, 'XTick', []);
set(gca, 'YTick', []);
colormap(tolcoldiv(200));
colorbar;
set(gca, 'FontSize', fontsize);

print([figdir 'real_face_parameters-wmargins.pdf'], '-dpdf', '-r600');
%unix(['cd ' figdir ' && ' pdfcrop ' real_face_parameters-margins.pdf real_face_parameters.pdf']);
%unix(['cd ' figdir ' && ' convert ' real_face_parameters.eps real_face_parameters.pdf']);

% Matrix
h = figure;
imagesc(bsxfun(@plus, col, row), [-10, 10]);
colormap(tolcoldiv(200));
set(gca, 'YTick', []);
set(gca, 'XTick', []);
colorbar;
xlabel('faces');
ylabel('pixels');
set(gca, 'FontSize', fontsize);
print([figdir 'real_face_parameter_matrix-wmargins.pdf'], '-dpdf', '-r600');


% Example faces
n = 10;
for i=1:n
    b = Blat(:, i);
    h = figure;
    imagesc(reshape(b, 32, 32), [0, 18.8]);
    axis equal
    axis tight
    set(gca, 'XTick', []);
    set(gca, 'YTick', []);
    colormap(gray(200));
    print([figdir 'real_face_factor_' int2str(i) '-wmargins.pdf'], '-dpdf', '-r600');
end


%
% Climate data
%
load([datadir 'worldclim.mat']);
load([resdir 'worldclim.mat']);

% Parameter matrix
h = figure;
imagesc(bsxfun(@plus, col, row), [-10, 10]);
colormap(tolcoldiv(200));
set(gca, 'YTick', []);
set(gca, 'XTick', 12*(0:3)+7);
set(gca, 'XTickLabel', {'t_{min}', 't_{max}', 't_{avg}', 'rain'});
line([12.5 24.5 36.5; 12.5 24.5 36.5], repmat([0.5; 2575.5], 1, 3), 'color', 'k');
colorbar;
set(gca, 'FontSize', fontsize);

print([figdir 'real_worldclim_parameter_matrix-wmargins.pdf'], '-dpdf', '-r600');

% Parameter per attribute bar plot
colors = [repmat([0, 139 206], 12, 1); repmat([180 221 247], 12, 1); repmat([249 189 126], 12, 1); repmat([208 50 50], 12, 1)]./255;
fHand = figure;
aHand = axes('parent', fHand);
hold(aHand, 'on')
for i=1:length(row), barh(i, row(i), 'parent', aHand, 'facecolor', colors(i,:)); end
set(gca, 'YTick', 12*(0:3)+7);
set(gca, 'YTickLabel', {'t_{min}', 't_{max}', 't_{avg}', 'rain'});
set(gca, 'FontSize', fontsize);
ylim([0.5,48.5]);
print([figdir 'real_worldclim_parameter_barplot-wmargins.pdf'], '-dpdf', '-r600');

%
% NPAS data
%
load([resdir 'NPAS']);
h = figure;
imagesc(bsxfun(@plus, col, row), [-10, 10]);
colormap(tolcoldiv(200));
set(gca, 'YTick', []);
set(gca, 'XTick', []);
colorbar;
xlabel('questions');
ylabel('answers');
set(gca, 'FontSize', fontsize);
print([figdir 'real_npas_parameter_matrix-wmargins.pdf'], '-dpdf', '-r600');

%
% HPI data
%
load([resdir 'HPI']);
h = figure;
imagesc(bsxfun(@plus, col, row), [-10, 10]);
colormap(tolcoldiv(200));
set(gca, 'YTick', []);
set(gca, 'XTick', []);
colorbar;
xlabel('months');
ylabel('locations');
set(gca, 'FontSize', fontsize);
print([figdir 'real_hpi_parameter_matrix-wmargins.pdf'], '-dpdf', '-r600');

%
% news data
%
load([resdir 'news']);
h = figure;
imagesc(bsxfun(@plus, col, row), [-10, 10]);
colormap(tolcoldiv(200));
set(gca, 'YTick', []);
set(gca, 'XTick', []);
colorbar;
xlabel('terms');
ylabel('documents');
set(gca, 'FontSize', fontsize);
print([figdir 'real_news_parameter_matrix-wmargins.pdf'], '-dpdf', '-r600');