#!/usr/bin/env python

from mpl_toolkits.basemap import Basemap
import matplotlib.pyplot as plt
import numpy as np
import matplotlib

# Some colourmaps
cols = []
for x in np.linspace(0, 1, 256):
    rcol = 0.237 - 2.13*x + 26.92*x**2 - 65.5*x**3 + 63.5*x**4 - 22.36*x**5    
    gcol = ((0.572 + 1.524*x - 1.811*x**2)/(1 - 0.291*x + 0.1574*x**2))**2
    bcol = 1/(1.579 - 4.03*x + 12.92*x**2 - 31.4*x**3 + 48.6*x**4 - 23.36*x**5)
    cols.append((rcol, gcol, bcol))

tol_diverging = matplotlib.colors.LinearSegmentedColormap.from_list("tol_diverging", cols)

from scipy.special import erf

cols = []
for x in np.linspace(0,1, 256):
	rcol = (1 - 0.392*(1 + erf((x - 0.869)/ 0.255)))
	gcol = (1.021 - 0.456*(1 + erf((x - 0.527)/ 0.376)))
	bcol = (1 - 0.493*(1 + erf((x - 0.272)/ 0.309)))
	cols.append((rcol, gcol, bcol))

tol_sequential = matplotlib.colors.LinearSegmentedColormap.from_list("tol_sequential", cols)

# Load coordinates
coord = np.loadtxt('../data/real/worldclim/worldclim_coordinates.csv', delimiter=',', skiprows=1)
lon = coord[:,0]
lat = coord[:,1]




# Load data
data = np.loadtxt('../results/real/worldclim_col_parameter.txt')

# Some special numbers
min_lon = min(lon) #-15. # Use instead of min(lon) for better-looking maps; can leave Azores out of the plot

# These are used to make sure the colour map has the correct range
max_val =  5
min_val = -5

# Width and height
width  = 5000000.
height = 5500000.

# Center
lat_0=(max(lat) - min(lat))/2.0 + min(lat)
lon_0=(max(lon) - min(lon))/2.0 + min(lon)

# Initialize the map
# Giving the corners doesn't seem to work...
#map = Basemap(projection="laea", llcrnrlat=min(lat), urcrnrlat=max(lat), llcrnrlon=-15., urcrnrlon=max(lon), lat_0=(max(lat) - min(lat))/2.0 + min(lat), lon_0=(max(lon)-min(lon))/2.0 + min(lon),  resolution='l')

map = Basemap(projection="laea", resolution="l", width=width, height=height, lat_0=lat_0, lon_0=lon_0)

x, y = map(lon, lat)



map.drawcoastlines()
map.drawcountries()
map.drawparallels(np.arange(30., 81, 10.))
map.drawmeridians(np.arange(-30., 31, 20.))

map.scatter(x, y, s=6, marker='.', c=data, cmap=tol_diverging, vmin=min_val, vmax=max_val)
cbar = plt.colorbar(orientation='horizontal',shrink=0.6, pad=0.05)
cbar.set_ticks([-5, -2.5, 0, 2.5, 5])

plt.savefig('../figs/real_worldclim_parameter_map-wmargins.pdf')
plt.clf()

#plt.show()
