function CplotNoise(minNoise, noiseInc, noiseIters, nInstances, dataName, nmfName, svdName, canName, saveName)

% Params.
FontSize = 30;
mn = 10;
LW = 1.2;
MarkerSize = 10;

% Find noise range.
noise = nan(noiseIters, 1);
for i = 1 : noiseIters
    noise(i) = minNoise + (i-1)*noiseInc;
end

load(dataName);

load(canName);
load(nmfName);
load(svdName);

resultsCan = nan(noiseIters, nInstances);
resultsNMF = nan(noiseIters, nInstances);
resultsSVD = nan(noiseIters, nInstances);

%% Frobenius error
for i = 1 : noiseIters
    for j = 1 : nInstances
        resultsCan(i, j) = frobRelative(Aorig{i}{j}, MaxProduct(Bcan{i}{j}, Ccan{i}{j}));
        resultsNMF(i, j) = frobRelative(Aorig{i}{j}, Bnmf{i}{j}*Cnmf{i}{j});
        resultsSVD(i, j) = frobRelative(Aorig{i}{j}, Bsvd{i}{j}*Csvd{i}{j});
    end
end

errorbar(noise, mean(resultsCan, 2), std(resultsCan, 0, 2), '-xr', ...
    'LineWidth', LW, 'markers', MarkerSize);
hold on
errorbar(noise, mean(resultsNMF, 2), std(resultsNMF, 0, 2), '-xb', ...
    'LineWidth', LW, 'markers', MarkerSize);
errorbar(noise, mean(resultsSVD, 2), std(resultsSVD, 0, 2), '-xk', ...
    'LineWidth', LW, 'markers', MarkerSize);

xlabel('Noise', 'interpreter', 'latex', 'fontsize', FontSize);
ylabel('Frobenius error', 'interpreter', 'latex', 'fontsize', FontSize);
set(gca,'fontsize', FontSize-8);

axis tight

hold off
saveas(gcf, saveName, 'pdf');
close all

end


function err_ = frobRelative(A, A_)
err_ = norm(A-A_, 'fro') / norm(A, 'fro');
end




