function [ C ] = tolcoldiv( n )
%TOLCOLDIV Paul Tol's diverging data color scheme
%   Colormap for Paul Tol's diverging scheme. Good for continuous 
%   diverging data. 
%
%   Usage:
%   TOLCOLDIV(n) returns n-by-3 colormap from the scheme. 
%
%   TOLCOLDIV is the same as TOLCOLDIV(size(colormap, 1))
%
%   Source: Paul Tol: Colour Schemes. SRON Technical Note
%   SRON/EPS/TN/09-002, 29 Dec 2012
%
%   See also: 
%   TOLCOLSEQ TOLCOLRAINBOW TOLCOLQUAL


if nargin == 0
    n = size(colormap, 1);
end

if n < 2, error('colormap must have at least 2 colours'); end

C = nan(n, 3);
x  = (0:(n-1))./(n-1); % x \in [0,1]
x2 = x.^2;
x3 = x.^3;
x4 = x.^4;
x5 = x.^5;
C(:,1) = 0.237 - 2.13*x + 26.92*x2 - 65.5*x3 + 63.5*x4 - 22.36*x5; % R
C(:,2) = ((0.572 + 1.524*x - 1.811*x2)./(1 - 0.291*x + 0.1574*x2)).^2; % G
C(:,3) = 1./(1.579 - 4.03*x + 12.92*x2 - 31.4*x3 + 48.6*x4 - 23.36*x5); % B

end

