function [Cbest, thetaRowBest] = LatRegression(A, B, thetaCol, varargin)
tic
%% Parameter.
NITER = 25;
verbose = 1;
for i = 1 : numel(varargin)
    if isequal(varargin{i}, 'NITER')
        NITER = varargin{i+1};
    end
    if isequal(varargin{i}, 'verbose')
        verbose = varargin{i+1};
    end
end


%% Initialize the factors and the relaxation parameters.
[n, m] = size(A);
k = 1;
C = lsqnonneg(B, A);


%% Initizlize the relaxation parameters.
thetaRow = 0;
Bbest = B;
Cbest = C;
thetaColBest = thetaCol;
thetaRowBest = thetaRow;
errorBest = MixTropErrorRelative(A, Bbest, Cbest, thetaColBest, thetaRowBest);


%% Alternatingly update the factors and the relaxation parameters.
for iter = 1 : NITER
    for j = 1 : m
        [C(:, j), thetaRow(j)] = ...
            solveMixRegresseon(A(:, j), B, C(:, j), thetaCol, thetaRow(j));
    end
    
    errorNew = MixTropErrorRelative(A, B, C, thetaCol, thetaRow);
    if errorNew < errorBest
        errorBest = errorNew;
        Cbest = C;
        thetaRowBest = thetaRow;
    end
    if verbose == 1
        fprintf('MixTrop [iter %d]   error: %9.4f\n', ...
            iter, errorNew);
    end
end
toc
end